# Equation

A ParagraphElement representing an equation.

**Type:** object

## Properties

- **suggestedInsertionIds** (array of string): The suggested insertion IDs. An Equation may have multiple insertion IDs if it's a nested suggested change. If empty, then this is not a suggested insertion.
- **suggestedDeletionIds** (array of string): The suggested deletion IDs. If empty, then there are no suggested deletions of this content.
